@@ -221,8 +221,7 @@ const string parallel_string = "parallel";
 const string time_limit_string = "time_limit";
 const string options_file_string = "options_file";
 
-/** SCIP/HiGHS Objective sense */
-enum objSense { OBJSENSE_MINIMIZE = 1, OBJSENSE_MAXIMIZE = -1 };
+// enum objSense { OBJSENSE_MINIMIZE = 1, OBJSENSE_MAXIMIZE = -1 };
 
 struct HighsOptionsStruct {
   // Options read from the command line
@@ -272,15 +271,6 @@ struct HighsOptionsStruct {
   bool less_infeasible_DSE_check;
   bool less_infeasible_DSE_choose_row;
   bool use_original_HFactor_logic;
-  // Options for iCrash
-  bool icrash;
-  bool icrash_dualize;
-  std::string icrash_strategy;
-  double icrash_starting_weight;
-  int icrash_iterations;
-  int icrash_approximate_minimization_iterations;
-  bool icrash_exact;
-  bool icrash_breakpoints;
 
   // Options for MIP solver
   int mip_max_nodes;
@@ -606,45 +596,6 @@ class HighsOptions : public HighsOptionsStruct {
         &use_original_HFactor_logic, true);
     records.push_back(record_bool);
 
-    record_bool =
-        new OptionRecordBool("icrash", "Run iCrash", advanced, &icrash, false);
-    records.push_back(record_bool);
-
-    record_bool =
-        new OptionRecordBool("icrash_dualize", "Dualise strategy for iCrash",
-                             advanced, &icrash_dualize, false);
-    records.push_back(record_bool);
-
-    record_string =
-        new OptionRecordString("icrash_strategy", "Strategy for iCrash",
-                               advanced, &icrash_strategy, "ICA");
-    records.push_back(record_string);
-
-    record_double = new OptionRecordDouble(
-        "icrash_starting_weight", "iCrash starting weight", advanced,
-        &icrash_starting_weight, 1e-10, 1e-3, 1e50);
-    records.push_back(record_double);
-
-    record_int = new OptionRecordInt("icrash_iterations", "iCrash iterations",
-                                     advanced, &icrash_iterations, 0, 30, 200);
-    records.push_back(record_int);
-
-    record_bool = new OptionRecordBool("icrash_exact",
-                                       "Exact subproblem solution for iCrash",
-                                       advanced, &icrash_exact, false);
-    records.push_back(record_bool);
-
-    record_bool = new OptionRecordBool("icrash_breakpoints",
-                                       "Exact subproblem solution for iCrash",
-                                       advanced, &icrash_breakpoints, false);
-    records.push_back(record_bool);
-
-    record_int = new OptionRecordInt(
-        "icrash_approximate_minimization_iterations",
-        "iCrash approximate minimization iterations", advanced,
-        &icrash_approximate_minimization_iterations, 0, 50, 100);
-    records.push_back(record_int);
-
     record_bool = new OptionRecordBool(
         "less_infeasible_DSE_check", "Check whether LP is candidate for LiDSE",
         advanced, &less_infeasible_DSE_check, true);
